@@ -36,22 +36,18 @@ def unversioned_files(path, binary_ext):
             yield path + "/" + filename
 
 
-def difference(from_vsn, is_internal, filename_source, rev, cached):
-    op = diff if from_vsn else file_diff
-
-    is_change = False
+def difference(from_vsn, is_internal, path, rev, cached):
     if not rev:
         rev = "HEAD"
         if not is_internal:
             rev += "..remotes/origin/HEAD"
 
-    lineno = 0
+    loc_re = re.compile(r"@@ \-\d+?(?:,\d+?)? \+(\d+?)(?:,\d+?)? @@")
+    code = None
     context = []
     skip = False
-    code = None
-    loc_re = re.compile(r"@@ \-\d+?(?:,\d+?)? \+(\d+?)(?:,\d+?)? @@")
     body = False
-    for line in op(filename_source, rev, cached):
+    for line in (diff if from_vsn else file_diff)(path, rev, cached):
         try:
             line = line.decode("utf-8")
         except UnicodeError:
@@ -59,44 +55,45 @@ def difference(from_vsn, is_internal, filename_source, rev, cached):
             continue
 
         if line.startswith("+++"):
-            filename = line[len("+++ b/"):]
-            filename = norm_path_sep(filename)
-            # skip whole file
+            filename = norm_path_sep(line[len("+++ b/"):])
             skip = False
             body = False
 
         elif line.startswith("Binary files"):
+            # skip whole file
             skip = True
 
         if skip:
             continue
 
         if line.startswith("@@"):
-            if code is not None and len(code.content) != len(context):
-                yield code, context, None
+            if code and len(code.content) != len(context):
+                yield code, context
 
-            loc_m = re.match(loc_re, line)
-            start_lincol = (int(loc_m.group(1)) - 1, 0)
-            code = Fragment(filename, [], 0, 0, start_lincol, start_lincol)
+            code = Fragment(filename, [],
+                            start_lincol=(int(re.match(loc_re, line).group(1)) - 1, 0))
             context = []
-            lineno = start_lincol[0]
             body = True
 
         elif body:
             if line.startswith(' '):
                 code.extend(line[1:] + '\n')
-                context.append(lineno)
-                lineno += 1
+                context.append(code.end_lincol[0])
             elif line.startswith('+'):
                 code.extend(line[1:] + '\n')
-                lineno += 1
 
             elif line.startswith('\\'):
-                # message backslash + space
-                yield code.copy().clear(False), None, line[2:]
+                # backslash + space
+                message = line[2:]
+                if message == "No newline at end of file":
+                    if code and code.content: # remove previously added newline
+                        code = code.slice(end=code.end_pos - 1, after_inner=True)
+                else:
+                    print("{0}:{1}: unexpected version control message: {2}"
+                          .format(code.filename, code.end_lincol[0], message))
 
     if code and len(code.content) != len(context):
-        yield code, context, None
+        yield code, context
 
 
 def update_files(path, rev=None):
@@ -161,8 +158,7 @@ def update(path):
     return exec_command(cmd, path)
 
 
-# -------------
-
+# ----------------------------------------------------------------------------
 
 def add(path):
     if path == "":
@@ -200,12 +196,10 @@ def exec_command(cmd_args, cwd=None):
             print_over("fetching" if cmd_args[0] in {"status", "diff", "update", "remote"}
                        else "applying", cmd_args[0], ellipsis="...")
         output = subprocess.check_output(cmd, cwd=cwd)
-    except OSError as err:
+    except (OSError, ValueError) as err:
         print("git", cmd_args[0], "error:", err)
-    except ValueError as err:
-        print("git", cmd_args[0], "error:", err)
-    except Exception as err:
-        print("git", cmd_args[0], "unexpected error", err)
+    except subprocess.CalledProcessError as err:
+        print("git", cmd_args[0], "error", err)
     else:
         if not silent:
             print_over("done")
@@ -231,12 +225,12 @@ def norm_path_sep(filename):
     return re.sub(r"\\", "/", filename)
 
 
-def run_diff(from_vsn, is_internal, path, rev, cached):
+def run_diff(from_vsn, is_internal, path, rev, cached, unversioned=False):
     if from_vsn:
         remote_head = update_remotes(path)
         print("Current revision:", get_revision(path))
 
-    if from_vsn and is_internal:
+    if from_vsn and is_internal and unversioned:
         binary_ext = {".png", ".jpg", ".jpeg", ".gif", ".pyc"}
         for filename in unversioned_files(path, binary_ext):
             filename, text = single_text(filename)
