@@ -48,7 +48,6 @@ def glossary_pre(_):
 
 def glossary(toolname, document, reports, data):
     """Unused glossary terms or within glossary only."""
-
     if document.code.filename not in data["glossary_filenames"]:
         return reports
 
@@ -58,14 +57,13 @@ def glossary(toolname, document, reports, data):
                 for line in def_node.head.code.splitlines():
                     line_strip = str(line).strip()
                     if line_strip in data["terms_glossary"]:
-                        message = "term used only within glossary"
-                        reports.append(Report('I', toolname, def_node.head.code, message))
+                        reports.append(Report('I', toolname, def_node.head.code,
+                                              "term used only within glossary"))
                         break
                     if line_strip in data["terms"]:
                         break
                 else:
-                    message = "unused term"
-                    reports.append(Report('I', toolname, def_node.head.code, message))
+                    reports.append(Report('I', toolname, def_node.head.code, "unused term"))
 
     return reports
 
@@ -78,17 +76,18 @@ def link_titles_pre(_):
 
 def link_titles(toolname, document, reports, data):
     """Find internal (ref) links title mismatches the heading title."""
-
     for node in rst_walker.iter_node(document.body, "role"):
         if rst_walker.is_of(node, "*", "ref") and node.head:
             id_str = str(node.id.code).strip()
             for target, title_head in data.items():
                 if target == id_str:
-                    sim = SequenceMatcher(lambda x: x == " ", str(title_head).lower(),
+                    sim = SequenceMatcher(lambda x: x == " ", str(title_head.code).lower(),
                                           str(node.head.code).lower()).ratio()
                     if sim < 0.9:
-                        message = "link title mismatches heading title: {:4.0%}".format(sim)
-                        reports.append(Report('W', toolname, node.head.code, message, title_head))
+                        reports.append(
+                            Report('W', toolname, node.head.code,
+                                   "link title mismatches heading title: {:4.0%}".format(sim),
+                                   title_head))
 
     return reports
 
@@ -116,7 +115,6 @@ def local_targets_pre(_):
 
 def local_targets(toolname, reports, data):
     """Find internal (ref) links used on same page only."""
-
     for node in data["targets"]:
         is_same_file = False
         is_multi = False
@@ -132,8 +130,7 @@ def local_targets(toolname, reports, data):
         # false positives: non heading targets, title not heading
         if is_same_file and not is_multi:
             if not id_str.startswith("fig-") and not id_str.startswith("tab-"):
-                message = "local target"
-                reports.append(Report('I', toolname, node.id.code, message))
+                reports.append(Report('I', toolname, node.id.code, "local target"))
 
     return reports
 
@@ -147,6 +144,7 @@ def page_name(toolname, document, reports):
     for word in re.split(r"[_-]", page):
         page_split.append(porter_stemmer.stem(word, 0, len(word)-1))
 
+    threshold = (0.5, 0.33, 0.25)
     for node in rst_walker.iter_node(document.body, "sect", enter_pos=False):
         head = str(node.name.code).lower().strip()
         head = re.sub(r"\b(\w)\-", r"\1", head)
@@ -186,16 +184,11 @@ def page_name(toolname, document, reports):
         if page == ''.join(acronym):
             sim = 1
 
-        if sim < 0.5:
-            severity = 'I'
-            if sim < 0.25:
-                severity = 'E'
-            elif sim < 0.33:
-                severity = 'W'
-
-            message = "page title - filename mismatch {:4.0%}".format(sim)
-            reports.append(Report(severity, toolname, node.name.code, message,
-                                  Fragment(document.code.filename, page)))
+        if sim < threshold[0]:
+            reports.append(
+                Report(Report.map_severity(threshold, sim), toolname, node.name.code,
+                       "page title - filename mismatch {:4.0%}".format(sim),
+                       Fragment(document.code.filename, page)))
 
         # break to only process only the first heading
         break
@@ -205,14 +198,12 @@ def page_name(toolname, document, reports):
 
 def tool_title(toolname, document, reports):
     """Check if a heading matches the tool name in the ref box."""
-
     last_re = re.compile(r"(?:\-> |\A)([^>]*?)(?:\.\.\.)?\Z")
     for node in rst_walker.iter_node(document.body, "sect", enter_pos=False):
         node_next = node.next
         if node_next.node_name == "text" and node.code.isspace():
             node_next = node_next.next
-        if (not rst_walker.is_of(node_next, "dir", "admonition") or
-                str(rst_walker.get_attr(node_next, "class")).strip() != "refbox"):
+        if not rst_walker.is_of(node_next, "dir", "reference"):
             continue
 
         heading_str = str(node.name.code).strip()
@@ -227,13 +218,14 @@ def tool_title(toolname, document, reports):
                     sim = SequenceMatcher(lambda x: x == " ", last_m.group(1),
                                           heading_str).ratio()
                     if max(sim, 0) > sim_max:
-                        tool_max = node_role.body.code.slice_match_obj(last_m, 1, True)
+                        tool_max = node_role.body.code.slice_match(last_m, 1, True)
                         sim_max = sim
 
         else:
-            message = Report.missing(what="tool name match", where="in ref box")
-            message += ":{:4.0%}".format(sim_max)
-            reports.append(Report('W', toolname, node.name.code, message, tool_max))
+            reports.append(
+                Report('W', toolname, node.name.code,
+                       Report.missing(what="tool name match", where="in ref box") +
+                       ":{:4.0%}".format(sim_max), tool_max))
 
     return reports
 
@@ -263,11 +255,9 @@ def unused_targets_pre(_):
 
 def unused_targets(toolname, reports, data):
     """Find unused internal (ref) targets."""
-
     for node in data["targets"]:
         if str(node.id.code).strip() not in data["links"]:
-            message = "unused target"
-            reports.append(Report('W', toolname, node.id.code, message))
+            reports.append(Report('W', toolname, node.id.code, "unused target"))
 
     return reports
 
